/**
 * 
 */
package buffered;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * Example for working with buffered io in java
 * 
 * See the links
 *    https://howtodoinjava.com/java/io/how-java-io-works-internally/
 *    https://howtodoinjava.com/java/io/java-write-to-file/
 *    https://www.baeldung.com/java-buffered-reader
 *    
 * @author pvassil
 *
 */
public class MainApp {

	public static void main(String[] args) throws FileNotFoundException {
		//Parser happy day
		String bookFilePath = "Books.txt"; 
		String bookDelimiter = "\\|";
		processInputFile(bookFilePath, bookDelimiter);

		//Parser rainy day
		bookFilePath = "ThisFileDoesNotExist.txt"; 
		bookDelimiter = "\\|";
		processInputFile(bookFilePath, bookDelimiter);

		String reportFilePath = "./ReportOfStrings.txt";
		List<String> sages = new ArrayList<String>(Arrays.asList("Chilon", "Anacharsis", "Cleobulus", "Pittacus", "Bias", "Thales",  "Solon"));
		constructReport(reportFilePath, sages);
	}//end main



	private static void constructReport(String reportFilePath, List<String> sages) {
		Reporter reporter = new Reporter();
		try {
			reporter.reportToTabbedTextFile(reportFilePath, sages);
		} catch (IOException e) {
			System.err.println(e.getMessage());
		}
	}

	private static void processInputFile(String bookFilePath, String bookDelimiter) {
		Parser parser = new Parser();
		try {
			parser.parse(bookFilePath, bookDelimiter);
		}catch(FileNotFoundException e) { //before mama class IOException
			System.err.println(e.getLocalizedMessage());
		} 
		catch (IOException e) {
			System.err.println("IOException: Failed to perform Parser.parse() for" + bookFilePath + "with " +  bookDelimiter + "\nCould not read line from input file stream" + e.getLocalizedMessage() + "\n");
		}
	}//end processInputFile
	
}
