/**
 * A simple example where we open a file, read its contents,
 * make them tab-separated and turn them to upper case,
 * before writing them to an output file.
 * 
 * Very close to the examples of the course's textbook "Absolute Java"
 * 
 * @author pvassil
 *
 */
package examples;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;


public final class LineIOExample {


	public static void main(String[] args) {

		String inputFileName = "Books.txt";
		String outputFileName = "BooksProcessed.txt";

		BufferedReader inputStream = null;
		PrintWriter outputStream = null;

		try {

			inputStream = new BufferedReader(new FileReader(inputFileName));

			try {
				outputStream = new PrintWriter(new FileWriter(outputFileName));
			} catch (IOException e) {
				System.err.println("Could not open output file stream");
				e.printStackTrace();
			}

			String nextInputLine = "";
			try {
				while ((nextInputLine = inputStream.readLine()) != null) {
					String[] stringParts = nextInputLine.split("\\|");
					// just "|" is a wild-character in reg. ex., cannot do it
					String outputLine = "";
					if (stringParts.length > 0) {
						for(String s: stringParts) {
							outputLine += s.toUpperCase() + "\t";
						}
					}
					//can you spot the small glitch and fix it before the println?
					outputStream.println(outputLine);	
				}
			} catch (IOException e) {
				System.err.println("Could not read line from input file stream");
				e.printStackTrace();
			}
		} //of the outermost try, to open the inputStream
		catch (FileNotFoundException e) {
			System.err.println("Could not open input file stream");
			e.printStackTrace();
		} //of the catch
		finally {
			if (inputStream != null) {
				try {
					inputStream.close();
				} catch (IOException e) {
					System.err.println("Could not close input file stream");
					e.printStackTrace();
				}
			}
			if (outputStream != null) {
				outputStream.close();  //nothing to throw, if sth is closed already
			}

			System.out.println("Done.");
		}
	}//end main()

}//end class


